@@ -187,36 +187,33 @@ def get_chapter_beg_end(tg, req_chapter):
                                 'ڶʮ Ĵ',\
                                 'ڶʮ '],
 
-                        '':['Ҫʾ',\
-                                'ŻƱA˽ļ֤ȯͶʻսʾ',\
-                                'ϸͶ߳ŵ',\
-                                'Ͷ߸֪',\
-                                'һǰ',\
+                        '':['һͬ',\
+                                'ǰ',\
                                 '',\
-                                'ŵ',\
-                                'ġ˽ļĻ',\
-                                '塢˽ļĽṹ',\
-                                '˽ļļ',\
-                                'ߡ˽ļĳ뱸',\
-                                'ˡ˽ļ깺غת',\
+                                'ġŵ',\
+                                '塢Ļ',\
+                                'ݶļ',\
+                                'ߡĳ뱸',\
+                                'ˡ깺ؼת',\
                                 'š˵Ȩ',\
                                 'ʮݶ˴ἰճ',\
-                                'ʮһ˽ļݶĵǼ',\
-                                'ʮ˽ļͶ',\
-                                'ʮ˽ļĲƲ',\
-                                'ʮġʽ㽻հ',\
-                                'ʮ塢Ͷָķ͡ȷϺִ',\
-                                'ʮ˽ļʲĹֵͻƺ',\
-                                'ʮߡ˽ļķ˰',\
-                                'ʮˡ˽ļ',\
-                                'ʮšϢ¶뱨',\
+                                'ʮһݶĵǼ',\
+                                'ʮͶ',\
+                                'ʮͶʾָ',\
+                                'ʮġĲƲ',\
+                                'ʮ塢ָķ͡ȷϺִ',\
+                                'ʮʽ㽻հ',\
+                                'ʮߡԽȨ״',\
+                                'ʮˡʲĹֵͻƺ',\
+                                'ʮšķ˰',\
+                                'ʮ',\
+                                'ʮһϢ¶',\
                                 'ʮսʾ',\
-                                'ʮһ˽ļͬЧֹ',\
-                                'ʮ˽ļ',\
-                                'ʮΥԼ',\
-                                'ʮġĴ',\
-                                'ʮ塢ά',\
-                                'ʮ'],
+                                'ʮͬıֹƲ',\
+                                'ʮġΥԼ',\
+                                'ʮ塢Ĵ',\
+                                'ʮͬЧ',\
+                                'ʮߡ'],
                                 
                         '㷢':['һ ǰ',\
                                 ' ',\
